Found a way to save everyone 14% on input tokens on average during read file operations in Hermes Agent! This is now on main. `hermes update…
Nous Research has optimized token efficiency in their Hermes Agent, achieving an average 14% reduction in input token usage during file read operations. This optimization has been merged to the main c